@@ -1,20 +1,18 @@
+"""
+Implementation of features exctractors for both the teacher and the robot
+"""
+from typing import Optional
 import gym
 import torch.nn as nn
 import torch as th
 from stable_baselines3.common.torch_layers import BaseFeaturesExtractor
-from typing import Callable, Dict, List, Optional, Tuple, Type, Union
-from stable_baselines3.common.policies import ActorCriticPolicy
 
 
 class LSTMFeatureExtractor(BaseFeaturesExtractor):
-    """
-    :param observation_space: (gym.Space)
-    :param features_dim: (int) Number of features extracted.
-        This corresponds to the number of unit for the last layer.
-    """
+    """_summary_"""
 
     def __init__(self, observation_space: gym.spaces.Box, features_dim: int = 6):  # type: ignore
-        super(LSTMFeatureExtractor, self).__init__(observation_space, features_dim)
+        super().__init__(observation_space, features_dim)
         self.LSTM = nn.LSTM(input_size=features_dim, hidden_size=16, num_layers=1)
 
     def forward(self, observations: th.Tensor) -> th.Tensor:
@@ -24,15 +22,9 @@ class LSTMFeatureExtractor(BaseFeaturesExtractor):
         return self.LSTM_output + self.LSTM_hidden[0] + self.LSTM_hidden[1]
 
 
-import torch as th
-import gym.spaces
-import torch.nn as nn
-from stable_baselines3.common.torch_layers import BaseFeaturesExtractor
-
-
 class Robot2DFeatureExtractor(BaseFeaturesExtractor):
     def __init__(self, observation_space: gym.spaces.Dict, features_dim: int = 37):
-        super(Robot2DFeatureExtractor, self).__init__(
+        super().__init__(
             observation_space=observation_space, features_dim=features_dim
         )
 
@@ -59,7 +51,7 @@ class Robot2DFeatureExtractor(BaseFeaturesExtractor):
 
 class Robot1DFeatureExtractor(BaseFeaturesExtractor):
     def __init__(self, observation_space: gym.spaces.Dict, features_dim: int = 37):
-        super(Robot1DFeatureExtractor, self).__init__(
+        super().__init__(
             observation_space=observation_space, features_dim=features_dim
         )
 
@@ -94,6 +86,7 @@ class CustomCombinedExtractor(BaseFeaturesExtractor):
         extractors = {}
 
         total_concat_size = 0
+        chosen_model: Optional[nn.Module] = None
         # We need to know size of the output of this extractor,
         # so go over all the spaces and compute output feature sizes
         for key, subspace in observation_space.spaces.items():  # type: ignore
@@ -104,7 +97,7 @@ class CustomCombinedExtractor(BaseFeaturesExtractor):
                 total_concat_size += subspace.shape[1] // 4 * subspace.shape[2] // 4
             elif key == "vector":
                 # Run through a simple MLP
-                extractors[key] = nn.Linear(subspace.shape[0], 16)
+                extractors[key] = extractors[key]= nn.Linear(subspace.shape[0], 16)
                 total_concat_size += 16
 
         self.extractors = nn.ModuleDict(extractors)
